@@ -1,6 +1,6 @@
 from rest_framework import serializers
-from .models import AnalysisMonitor
 from rest_framework.serializers import CharField, IntegerField, JSONField
+from .models import AnalysisMonitor
 
 
 class AnalysisMonitorSerializer(serializers.ModelSerializer):
@@ -16,6 +16,11 @@ class AnalysisMonitorSerializer(serializers.ModelSerializer):
 
     def create(self, validated_data):
         request = self.context['request']
+        if 'page_url' not in validated_data:
+            validated_data['page_url'] = request.META.get('HTTP_REFERER', '')
+        if 'user_agent' not in validated_data:
+            validated_data['user_agent'] = request.META.get(
+                'HTTP_USER_AGENT', '')
         ip = request.META.get('HTTP_X_FORWARDED_FOR') if request.META.get(
             'HTTP_X_FORWARDED_FOR') else request.META.get('REMOTE_ADDR')
         validated_data['user_ip'] = ip
