@@ -3,7 +3,7 @@ from asgiref.sync import async_to_sync
 from channels.generic.websocket import WebsocketConsumer
 from bluedot_rest_framework import import_string
 
-EventChat = import_string('EVENT.chat.models')
+eventChat = import_string('event.chat.models')
 
 
 class ChatConsumer(WebsocketConsumer):
@@ -42,12 +42,12 @@ class ChatConsumer(WebsocketConsumer):
             'data': text_data_json.get('data', None),
         }
         if data["state"] == 0:
-            EventChat.objects.create(**data)
+            eventChat.objects.create(**data)
         elif data["state"] == 1:
             _id = text_data_json.get('id', None)
-            Event_chat_queryset = EventChat.objects.get(pk=_id)
-            Event_chat_queryset.state = 1
-            Event_chat_queryset.save()
+            event_chat_queryset = eventChat.objects.get(pk=_id)
+            event_chat_queryset.state = 1
+            event_chat_queryset.save()
             data['chat_id'] = _id
             # Send message to room group
             async_to_sync(self.channel_layer.group_send)(
@@ -59,15 +59,15 @@ class ChatConsumer(WebsocketConsumer):
             )
         elif data['state'] == 2:
             _id = text_data_json.get('id', None)
-            Event_chat_queryset = EventChat.objects.get(pk=_id)
-            Event_chat_queryset.state = 2
-            Event_chat_queryset.save()
+            event_chat_queryset = eventChat.objects.get(pk=_id)
+            event_chat_queryset.state = 2
+            event_chat_queryset.save()
 
         elif data['state'] == 5:  # 撤回
             _id = text_data_json.get('id', None)
-            Event_chat_queryset = EventChat.objects.get(pk=_id)
-            Event_chat_queryset.state = 0
-            Event_chat_queryset.save()
+            event_chat_queryset = eventChat.objects.get(pk=_id)
+            event_chat_queryset.state = 0
+            event_chat_queryset.save()
             send_data = {
                 'chat_id': _id,
                 'state': data['state']
