@@ -4,11 +4,11 @@ from channels.generic.websocket import WebsocketConsumer
 from bluedot_rest_framework import import_string
 from django.db.models import F
 
-EventComment = import_string('EVENT.comment.models')
-EventCommentSerializer = import_string('EVENT.comment.serializers')
+EventComment = import_string('event.comment.models')
+CommentSerializer = import_string('event.comment.serializers')
 
-EventCommentLike = import_string('EVENT.comment.like_models')
-EventCommentLikeSerializer = import_string('EVENT.comment.like_serializers')
+EventCommentLike = import_string('event.comment.like_models')
+EventCommentLikeSerializer = import_string('event.comment.like_serializers')
 
 
 class CommentConsumer(WebsocketConsumer):
