@@ -1,7 +1,7 @@
-from django.db import models
+from bluedot_rest_framework.utils.models import models, AbstractRelationTime
 
 
-class AbstractEventSchedule(models.Model):
+class AbstractEventSchedule(AbstractRelationTime):
     event_id = models.IntegerField()
 
     project_title = models.CharField(max_length=255, verbose_name='项目名称')
@@ -13,9 +13,6 @@ class AbstractEventSchedule(models.Model):
 
     speaker_ids = models.JSONField()
 
-    created = models.DateTimeField(auto_now_add=True)
-    updated = models.DateTimeField(auto_now=True)
-
     class Meta:
         abstract = True
 
