@@ -2,7 +2,7 @@ from bluedot_rest_framework.utils.serializers import CustomSerializer
 from bluedot_rest_framework import import_string
 
 
-EventSpeaker = import_string('EVENT.speaker.models')
+EventSpeaker = import_string('event.speaker.models')
 
 
 class EventSpeakerSerializer(CustomSerializer):
