@@ -7,7 +7,7 @@ from rest_framework.settings import APISettings
 USER_SETTINGS = getattr(settings, 'BLUEDOT_REST_FRAMEWORK', None)
 
 DEFAULTS_SETTINGS = {
-    'EVENT': {
+    'event': {
         'models': 'bluedot_rest_framework.event.models.Event',
         'serializers': 'bluedot_rest_framework.event.serializers.EventSerializer',
         'views': 'bluedot_rest_framework.event.views.EventView',
@@ -75,17 +75,36 @@ DEFAULTS_SETTINGS = {
             'views': 'bluedot_rest_framework.event.venue.views.EventVenueView',
         },
     },
-    'USER': {
+    'user': {
         'models': 'bluedot_rest_framework.user.models.User',
         'serializers': 'bluedot_rest_framework.user.serializers.UserSerializer',
         'views': 'bluedot_rest_framework.user.views.UserView',
     },
-    'WECHAT': {
-        'MINIPROGRAM': {
+    'category': {
+        'models': 'bluedot_rest_framework.category.models.Category',
+        'serializers': 'bluedot_rest_framework.category.serializers.CategorySerializer',
+        'views': 'bluedot_rest_framework.category.views.CategoryView',
+    },
+    'config': {
+        'models': 'bluedot_rest_framework.config.models.Config',
+        'serializers': 'bluedot_rest_framework.config.serializers.ConfigSerializer',
+        'views': 'bluedot_rest_framework.config.views.ConfigView',
+    },
+    'data_download': {
+        'models': 'bluedot_rest_framework.data_download.models.DataDownload',
+        'serializers': 'bluedot_rest_framework.data_download.serializers.DataDownloadSerializer',
+        'views': 'bluedot_rest_framework.data_download.views.DataDownloadView',
+        'user_models': 'bluedot_rest_framework.data_download.models.DataDownloadUser',
+        'user_serializers': 'bluedot_rest_framework.data_download.serializers.DataDownloadUserSerializer',
+        'user_views': 'bluedot_rest_framework.data_download.views.DataDownloadUserView',
+    },
+    'wechat': {
+        'models': 'bluedot_rest_framework.wechat.models.WeChatUser',
+        'miniprogram': {
             'APPID': '',
             'SECRET': ''
         },
-        'OFFIACCOUNT': {
+        'offiaccount': {
             'APPID': 'wx7c33b1edc5934d81',
             'SECRET': 'da0330d7394e1f620b43ccd118646d5e',
             'TOKEN': 'X1GOUqQcLipgwyhVYMPfagGIFqgbDHlF',
@@ -95,10 +114,10 @@ DEFAULTS_SETTINGS = {
         'login': {
             'consumers': 'bluedot_rest_framework.wechat.login.consumers.WechatLoginConsumer',
             'routing': 'bluedot_rest_framework.wechat.login.routing.websocket_urlpatterns',
+        },
 
-        }
     },
-    'UTILS': {
+    'utils': {
         'AES': {
             'iv': 'aSEDKOOuic5BDks1',
             'key': '9B1niuSzcISIHV5i',
@@ -112,14 +131,6 @@ DEFAULTS_SETTINGS = {
     }
 }
 
-# List of settings that may be in string import notation.
-IMPORT_STRINGS = (
-    'EVENT',
-    'USER',
-    'WECHAT',
-    'UTILS',
-)
-
 
 def merge_settings(DEFAULTS_SETTINGS, USER_SETTINGS):
     for key in USER_SETTINGS:
