@@ -6,21 +6,22 @@ from rest_framework.views import APIView
 from rest_framework.response import Response
 
 from bluedot_rest_framework.utils.oss import OSS
-from .. import OfficialAccount
+from .. import App
 from ..handle import WeChatUserSet
 from bluedot_rest_framework import import_string
 
 from .models import WeChatLogin
 
-User = import_string('USER.models')
+User = import_string('user.models')
 
 
 class WeChatLoginView(APIView):
     permission_classes = ()
 
     def get(self, request, *args, **kwargs):
+        appid = request.query_params.get('appid', '')
         scene_str = request.query_params.get('code', '')
-        result = OfficialAccount.qrcode.create({
+        result = App(appid).qrcode.create({
             'expire_seconds': 86400,
             'action_name': 'QR_STR_SCENE',
             'action_info': {
@@ -35,9 +36,10 @@ class WeChatLoginWebSocketView(APIView):
     permission_classes = ()
 
     def get(self, request, *args, **kwargs):
+        appid = request.query_params.get('appid', '')
         scene_str = request.query_params.get('scene_str', '')
         openid = request.query_params.get('openid', '')
-        user_info = OfficialAccount.user.get(openid)
+        user_info = App(appid).user.get(openid)
         token = WeChatUserSet(user_info=user_info).get_token()
         ws = create_connection(
             f"ws://{settings.ALLOWED_HOSTS[0]}/ws/wechat/login/" + scene_str)
