@@ -2,14 +2,15 @@ from rest_framework.serializers import SerializerMethodField
 from bluedot_rest_framework import import_string
 from bluedot_rest_framework.utils.serializers import CustomSerializer
 
-from bluedot_rest_framework.wechat.models import WeChatUser
+from bluedot_rest_framework.wechat.models import WeChatUser, WeChatUserOpenid
 
-User = import_string('USER.models')
-UserSerializer = import_string('USER.serializers')
+User = import_string('user.models')
+UserSerializer = import_string('user.serializers')
 
 
 class WeChatUserSerializer(CustomSerializer):
     profile = SerializerMethodField()
+    openid = SerializerMethodField()
 
     class Meta:
         model = WeChatUser
@@ -23,3 +24,11 @@ class WeChatUserSerializer(CustomSerializer):
             return serializer.data
         else:
             return None
+
+    def get_openid(self, queryset):
+        queryset = WeChatUserOpenid.objects.filter(
+            wechat_id=queryset.id).first()
+        return {
+            'openid': queryset.openid,
+            'subscribe': queryset.subscribe
+        }
